
#define HAVE_SYS_TIME_H
/* #undef HAVE_SYS_TIMEB_H */
#define HAVE_UNISTD_H


#define HAVE_GETTIMEOFDAY
/* #undef HAVE_GETLOCALTIME */
/* #undef HAVE_FTIME */
/* #undef HAVE_RINT */
#define HAVE_TIMEGM
/* #undef HAVE_ISNAN */
#define HAVE_STD_ISNAN
/* #undef HAVE_WINDOWS_H */
#define HAVE_MKDTEMP

#define GCC_ATOMIC_BUILTINS_FOUND

#define SYSTEM_EXPAT
#define ENABLE_SOUND
